superuser_interfaces library

Classes

MockSuperuser
Replicate behaviour of SuperuserInterface, which fulfilled requirements of testing.
OSString
Replicated String with modified matching mechnism applied depended on which OS is used. OSString will print unmodified string from input when calling toString.
OSStringsSet
A collection of OSString with every elements comply matching staregy when the first OSString inserted.
SuperuserInterface
Shared interface for evaluating superuser status when executing Flutter program.
SuperuserPlatform
Platform specified SuperuserInterface to retrive properties from plugins.

Exceptions / Errors

SuperuserProcessError
Indicate any errors encountered when fetching properties in SuperuserInterface.