OSString class abstract final

Replicated String with modified matching mechnism applied depended on which OS is used. OSString will print unmodified string from input when calling toString.

Constructors

OSString(String str, [int flag = DEFAULT_MATCH])
Get a default String matching behaviour depends on which OS is used or specify flag to override String matching staregy.
factory
OSString.allCapital(String str)
A String is going to compare in all captical letter.
const
factory
OSString.allSmall(String str)
A String is going to compare in all small letter.
const
factory
OSString.caseSensitive(String str)
Using bitwise operation of enumerated flag to concrete OSString.
const
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCaseAppliedString() String
Return a converted String based on case sensivity rules were used when matching.
toString() String
Represent the applied String from the constructors.
override

Operators

operator <=(String str) bool
Determine the given String is matched by applying comparison staregy from OSString.
operator ==(Object other) bool
Determine the given OSString has identical detection method as well as matched string representation.
override

Constants

DEFAULT_MATCH → const int
Apply matching staregy depending default behaviour of the OS.
MATCH_CAPITAL → const int
Enable matching Strings in captial letter.
MATCH_SMALL → const int
Enable matching Strings in small letter.