groups property
OSStringsSet
get
groups
Obtains all groups name that this user is associated.
Implementation
OSStringsSet get groups;
Obtains all groups name that this user is associated.
OSStringsSet get groups;