SuperuserProcessError class
Indicate any errors encountered when fetching properties in SuperuserInterface.
Constructors
- SuperuserProcessError({required int errorCode, required ({String entryPoint, String nativeAPI}) functionName, String message = "Result from native process has been returned with error code."})
-
Create SuperuserProcessError with given
errorCode.
Properties
- errorCode → int
-
Error code returned from native library.
final
- functionName → ({String entryPoint, String nativeAPI})
-
Name of functions from FFI that it cause this error thrown.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Message to explain errorCode.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace at the point where this error was first thrown.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited