SuperuserProcessError constructor

SuperuserProcessError({
  1. required int errorCode,
  2. required ({String entryPoint, String nativeAPI}) functionName,
  3. String message = "Result from native process has been returned with error code.",
})

Create SuperuserProcessError with given errorCode.

Optionally, provide a message for further explaination of error.

Implementation

SuperuserProcessError({
  required this.errorCode,
  required this.functionName,
  this.message =
      "Result from native process has been returned with error code.",
}) : assert(
       [
         functionName.entryPoint,
         functionName.nativeAPI,
       ].every((funcName) => funcName.trim().isNotEmpty),
     );