OSString.caseSensitive constructor
const
OSString.caseSensitive(
- String str
Using bitwise operation of enumerated flag to concrete OSString.
Flag value is a combination in 2-bit integer with enumerated
constants MATCH_CAPITAL, MATCH_SMALL and DEFAULT_MATCH
to determine OSString matching staregy. For constructing
OSStringsSet.caseSensitive, use MATCH_CAPTICAL | MATCH_SMALL
A String is going to compare with case sensivity, which exactly behave the same
outcome when using String.== for matching.
Implementation
/// A [String] is going to compare with case sensivity, which exactly behave the same
/// outcome when using [String.==] for matching.
const factory OSString.caseSensitive(String str) = _CaseSensitiveOSString;