operator == abstract method
Determine the given OSString has identical detection method as well as matched string representation.
This operator aims to design for handling data collection in Dart mainly (i.e.: Map and Set). For finding matched String in literal, uses <= operator instead.
Implementation
@mustBeOverridden
@override
bool operator ==(Object other);