Platform specified SuperuserInterface to retrive properties from plugins.
This cannot be used in tesing due to unpredictable expectation of properties. Therefore, MockSuperuser must be used to ensure all properties are controllable that all test results should be predictable.
- Implemented types
Constructors
- SuperuserPlatform()
- Create SuperuserPlatform for targeted platform.
Properties
- groups → OSStringsSet
-
Obtains all groups name that this user is associated.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActivated → bool
-
Determine this program is executed with superuser right.
no setterinherited
- isSuperuser → bool
-
Determine current user has superuser role.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- whoAmI → OSString
-
Retrive name of user, who run this program.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited